/*                              */
/* xemeraldia   ----- bitmaps.h */
/*                              */

#define char const char

#include "./bitmaps/star.xbm"

#include "./bitmaps/block1.xbm"
#include "./bitmaps/block2.xbm"
#include "./bitmaps/block3.xbm"
#include "./bitmaps/block4.xbm"
#include "./bitmaps/block5.xbm"
#include "./bitmaps/block6.xbm"
#include "./bitmaps/block1cr.xbm"
#include "./bitmaps/block2cr.xbm"
#include "./bitmaps/block3cr.xbm"
#include "./bitmaps/block4cr.xbm"
#include "./bitmaps/block5cr.xbm"
#include "./bitmaps/block6cr.xbm"

#include "./bitmaps/colorblock.xbm"
#include "./bitmaps/colorblockcr.xbm"

#include "./bitmaps/crush0.xbm"
#include "./bitmaps/crush1.xbm"
#include "./bitmaps/crush2.xbm"
#include "./bitmaps/crush3.xbm"
#include "./bitmaps/crush4.xbm"

#undef char
